.ll 6.5i
.TH PRINTCAL L "11-Feb-05"
.SH NAME
printcal - generate PostScript calendars by merging a user's desktop calendar
with added information
.SH SYNOPSIS
.nf
printcal [-a args] [-c filename(s)] -d 'month [year]' [-f format] [-h] [-i filename] [-m host] [-n] [-o filename] [-p] [-P queue] [-u name] [-v]
.fi
.SH DESCRIPTION
Printcal will merge added calendar information to a user's desktop calendar
from either a vCalendar format file or from one of Sun's calendar manager
programs (either CDE or Open Windows).  The resulting merged calendar is
in PostScript format that can be saved to a file and/or printed.

A file in the user's home directory (\f3.printcalrc\f1) controls which
appointments are automatically included or excluded.  See PRINTCALRC
below for more information.  The user will be asked to include any
appointments not covered in the RC file.

By default, appointments are gathered from a vCalendar format file.  This
can be changed to use one of the calendar manager programs by using the '-f'
option or by specifying the format to use in the \f3.printcalrc\f1 file
(see PRINTCALRC below).

By default, all files in a users home directory ending in ".cal" are considered
to be calendar files (in a format dictated by Sun's calendar manager) and
read in for holiday information.  This automatic action can be turned off by
the "-n" option or changed by the "-c" option.

Command line options override setting in the \f3.printcalrc\f1 file.
.SH OPTIONS
.IP "-a args"
Command line arguments to pass to "pcal" (see pcal(1)), the program that
actually creates the PostScript calendar.  Quotes must be used around the
arguments if there is any whitespace.  For example, to display moon icons
(-m option) and to set a left footer (-L option):

.nf
.in +5
printcal -a "-m -L 'Left Footer'" jan
.in -5
.fi
.IP "-c filename(s)"
List of calendar files to use when adding holidays.  These files should be
in the standard as dictated for Sun's calendar manager (see \f3cm(1)\f1).
.IP "-d 'month [year]'
Is the date of the calendar to create.  The current date will be used if not
given.  A month or a month AND a year can be listed.  The month
can be a number (from 1 to 12) or the name (i.e. march).  Enough of the
name must be given to uniquely identify the month.  If specifying both
the month and year, quotes must surround the date so that it will be seen
as one argument.  The following are valid ways of specifying the date:

.in +5
.nf
-d 3			(March of the current year)
-d march		(another way to say March of the current year)
-d '3 2008'	(March in the year 2008)
-d 'mar 2008'	(another way of saying March 2008)
.fi
.in -5
.IP "-f format"
Format of the input calendar.  Valid choices are \f2vcal\f1 (for vCalendar
format files), \f2cde\f1 to connect to the CDE calendar manager, or \f2ow\f1
to connect to the Open Windows calendar manager.
.IP "-h"
Show help (usage line plus a descripion of all arguments).
.IP "-i filename"
Name of the file in vCalendar format to use when processing vCalendar input.
.IP "-m machine"
Host to fetch the calendar from when using a calendar manager.  This will
default to the current machine \f2printcal\f1 is running on if it isn't
specified here or in the \f3.printcalrc\f1 file.
.IP "-n"
Indicates that no calendar files should be used.  By default, all files
ending in ".cal" in the users home directory will be automatically
read in for holiday information.
.IP "-o filename"
Filename to save the PostScript generated calendar to.
.IP "-p"
Tells \f2printcal\f1 to print the PostScript output.
.IP "-P queue"
Printer queue to send the formatted PostScript to (when the '-p' switch
is specified).  Default is the system's default printer.
.IP "-u user" 
User's calendar to get (when using a calendar manager).  This will default
to the current user running \f2printcal\f1 if it isn't specified here or in 
the \f3.printcalrc\f1 file.
.IP "-v"
Show the version number and exit.  No processing is done.
.SH PRINTCALRC
The \f3.printrc\f1 file consists of eight different lines: comment, blank,
user, host, holiday, include, exclude, and format.  The order of
the include and exclude lines are important.  The order in which they appear
will determine which is checked first (i.e. if an include line is found first,
includes will be checked before excludes).

A comment line starts with a pound sign and continues until the end of
the line.  Comment lines are ignored.

Blank lines have nothing on them except a newline.  Blank lines are also
ignored.

A user line is used to identify which user's calendar will be retrieved when
using a calendar manager.  This setting can be overridden by the "-u" command
line option.  If "-u" isn't used and there is no user line in
the \f3.printrc\f1 file, the default user is the account
running \f2printcal\f1.  The syntax is:

.nf
.in +5
User: <login name>
.in -5
.fi

The <login name> is the account name to use.  If there are multiple user
lines, the last one takes effect.

A host line is used to identify which host machine to fetch the calendar from
when using a calendar manager.  This setting can be overridden by the "-h"
command line option.  If "-h" isn't used and there is no host line in
the \f3.printrc\f1 file, the default host is the computer \f2printcal\f1 is
currently running on.  The syntax is:

.nf
.in +5
Host: <system name>
.in -5
.fi

The <system name> is the computer name to use.  If there are multiple machine
lines, the last one takes effect.

Holiday lines are used to add holidays to the calendar.  The syntax is:

.nf
.in +5
Holiday: <month>:<day>:<text>
.in -5
.fi

for those holidays that fall on a specific day and

.nf
.in +5
Holiday: <holiday>:[<text>]
.in -5
.fi

for those whose date changes each year (like Hanukkah).

The <month> field is the month for this holiday.  The <text> field is the text
that will be displayed in the calendar.  The <day> field can either be
numeric for a specific day, or a string describing a day.  Descriptions can
be of the form:

.in +5
.nf
nth day
.fi
.in -5

or

.in +5
.nf
nth day relative_to nth day
.fi
.in -5

For those holidays whose date changes each year, the description text is
optional (the ending colon must still be present).  If the text is not
given, the name of the holiday will be used as the text.  The <holiday>
field is the name of the holiday to find the date for.  This field is
case-insensitive.  The following holidays are supported:

.nf
.in +5
o Easter
o Hanukkah
.in -5
.fi

Since there are many spellings for Hanukkah, the following spellings are
all valid:

.nf
.in +5
.nm +1 1 1 10
.ti 1
Chanukah
.ti 1
Chanukkah
.ti 1
Hanukah
.ti 1
Hanukkah
.ti 1
Chanuka
.ti 1
Chanukka
.ti 1
Hanuka
.ti 1
Hanukka
.ti 1
Channukah
.ti 1
Channukkah
.ti 1
Hannukah
.ti 1
Hannukkah
.ti 1
Channuka
.ti 1
Channukka
.ti 1
Hannuka
.ti 1
Hannukka
.ti 1
Kannukah
.ti 1
Kanukkah
.ti 1
Kannuka
.ti 1
Kanukka
.ti 1
Ckannuka
.ti 1
Ckanukka
.ti 1
Ckannukah
.ti 1
Ckanukkah
.nm
.in -5
.fi

Descriptions are case-insensitive.  An example of the first form would be
"2nd thursday".  An example of the second form would be "1st monday after
3rd friday".  The "relative_to" term can be "after" or "before".  Legal
values for the "nth" terms can either be a number from 1-5; the string
"1st", "2nd", "3rd", "4th", or "5th"; or the string "last" (in limited cases).

The "nth" term cannot be set to "last" for either the first "nth" term in the
second form or for the second "nth" term in the second form when the
"relative_to" term is set to "after".  For the first form, "last" is valid
for the "nth" term.  The following are all illegal:

.nf
.in +5
last friday before 2nd wednesday
last friday after 2nd wednesday
1st tuesday after last sunday
.in -5
.fi

For the first two cases ("last friday..."), the description can just be set
to "last friday".  For the last case, this description takes the date into
the next month and so can be rewritten as such.

Include lines are of the form:

.nf
.in +5
Include: <pattern(s)>
.in -5
.fi

The <pattern(s)> field is a whitespace separated list of strings.  Each pattern
listed will be matched against an appointment to determine if it should be
included.  The pattern must be found within the appointment to be considered
a match.

Exclude lines are of the form:

.nf
.in +5
Exclude: <pattern(s)>
.in -5
.fi

The rules for Exclude lines are the same as for Include lines except that
if the pattern matches an appointment, that appointment is excluded.

The format line tells \f2printcal\f1 how to deal with the input calendar.
The default is to read a vCalendar format file.  The syntax for this line is:

.nf
.in +5
Format: <format>
.in -5
.fi

where <format> can be \f2vcal\f1 (for vCalendar format files), \f2cde\f1 (to
contact the CDE calendar manager), or \f2ow\f1 (to contact the Open Windows
calendar manager).
.SH FILES
.IP "$HOME/.printcalrc"
controls appointments to include or exclude automatically
.IP "$HOME/*.cal"
files containing holidays to add to the calendar
.SH EXAMPLE
Here is an example \f3.printrc\f1 file.

.nf
.in +5
# US Holidays
Holiday: Hanukkah:1st Day of Hanukkah
Holiday: Easter:
Holiday: 7: 4:Independence Day
Holiday: 9: 1st monday after 1st tuesday:Labor Day
Holiday: 9:22:Autumn Begins
Holiday:10:last sunday:Daylight Savings Ends
Holiday:12:25:Christmas

# Include list
Include: hair softball holiday vacation soccer ultimate dentist

# Exclude list
Exclude: roundtable withdrawl meeting report

# Use the Open Windows calendar manager
Format: ow
.in -5
.fi
.SH SEE ALSO
cm(1), cm_lookup(1), dtcm(1), dtcm_lookup(1), pcal(l)
.SH BUGS
None known, but notify author.
.SH AUTHOR
Adam Stein (adam@scan.mc.xerox.com)

